# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that initializes the GUIs that manage
radio stations.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: <mystilleef@gmail.com>
"""

name = "Play Button Plugin"
authors = ["Lateef Alabi-Oki <mystilleef@gmail.com>"]
version = 0.1
autoload = True
class_name = "PlayButtonPlugin"
short_description = "Play button plugin for striim"
long_description = """Play button plugin for striim."""

class PlayButtonPlugin(object):
	"""
	This class that initializes the play button for the player. 
	"""

	def __init__(self, player):
		"""
		Initialize the plug-in object.

		@param self: Reference to the PlayButtonPlugin instance.
		@type self: A PlayButtonPlugin object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__player = player
		self.__trigger = None

	def load(self):
		"""
		Initialize the PlayButtonPlugin instance.

		@param self: Reference to the PlayButtonPlugin instance.
		@type self: An PlayButtonPlugin object.
		"""
		from PlayButton.Trigger import Trigger
		self.__trigger = Trigger(self.__player)
		return

	def unload(self):
		"""
		Destroy the PlayButtonPlugin instance.

		@param self: Reference to the PlayButtonPlugin instance.
		@type self: An PlayButtonPlugin object.
		"""
		self.__trigger.destroy()
		return
