# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that initializes the striim's radio 
streaming engine.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: <mystilleef@gmail.com>
"""

name = "Streamer Plugin"
authors = ["Lateef Alabi-Oki <mystilleef@gmail.com>"]
version = 0.1
autoload = True
class_name = "StreamerPlugin"
short_description = "Streamer plugin for striim"
long_description = """Streamer plugin for striim."""

class StreamerPlugin(object):
	"""
	This class initializes the player's streamer.
	"""

	def __init__(self, player):
		"""
		Initialize the plug-in object.

		@param self: Reference to the StreamerPlugin instance.
		@type self: A StreamerPlugin object.

		@param editor: Reference to the text editor.
		@type editor: An Editor object.
		"""
		self.__player = player
		self.__manager = None

	def load(self):
		"""
		Initialize the StreamerPlugin instance.

		@param self: Reference to the StreamerPlugin instance.
		@type self: An StreamerPlugin object.
		"""
		from Streamer.StreamController import StreamController
		self.__manager = StreamController(self.__player)
		return

	def unload(self):
		"""
		Destroy the StreamerPlugin instance.

		@param self: Reference to the StreamerPlugin instance.
		@type self: An StreamerPlugin object.
		"""
		self.__manager.destroy()
		self.__manager = None
		return
