# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that manages all components of status
area.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE, TYPE_PYOBJECT

class Manager(GObject):
	"""
	This class manages all components of the status area.
	"""

	__gsignals__ = {
		"destroy": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
		"icon-position": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_PYOBJECT,)),
		"show-status-window": (SIGNAL_RUN_LAST, TYPE_NONE, (TYPE_PYOBJECT,)),
		"hide-status-window": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
	}

	def __init__(self, player):
		"""
		Initialize object.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		GObject.__init__(self)
		self.__init_attributes(player)
		from PopupMenu import PopupMenu
		PopupMenu(player)
		from Image import Image
		Image(self, player)
		from Label import Label
		Label(self, player)
		from Window import Window
		Window(self, player)
		from Cursor import Cursor
		Cursor(self, player)
		from thread import start_new_thread
		from StatusIcon import StriimStatusIcon
		start_new_thread(StriimStatusIcon, (self, player))
		self.__signal_id_1 = self.connect("destroy", self.__destroy_cb)

	def __init_attributes(self, player):
		"""
		Initialize data attributes.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__player = player
		from os.path import join, split
		cwd = split(globals()["__file__"])[0]
		glade_file = join(cwd, "Status.glade")
		from gtk.glade import XML
		self.__glade = XML(glade_file, domain="striim")
		self.__signal_id_1 = None
		return

	def __get_glade(self):
		return self.__glade

	glade = property(__get_glade)

	def destroy(self):
		"""
		Destroy object.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.
		"""
		self.emit("destroy")
		return

	def __destroy_cb(self, *args):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.
		"""
		from Striim.utils import disconnect_signal, delete_attributes
		disconnect_signal(self.__signal_id_1, self)
		del self
		self = None
		return
